@@ -33,10 +33,14 @@
 
 
 /*
- * $Id: dproto.h,v 1.18 2005/08/29 10:24:25 abe Exp $
+ * $Id: dproto.h,v 1.19 2008/04/15 13:32:58 abe Exp $
  */
 
 
+#if	defined(HASVXFSUTIL)
+_PROTOTYPE(extern void access_vxfs_ioffsets,(void));
+#endif	/* defined(HASVXFSUTIL) */
+
 _PROTOTYPE(extern void completevfs,(struct l_vfs *vfs, dev_t *dev));
 _PROTOTYPE(extern int is_file_named,(char *p, int nt, enum vtype vt, int ps));
 _PROTOTYPE(extern struct l_vfs *readvfs,(KA_T ka, struct vfs *la, struct vnode *lv));
